@@ -43,6 +43,10 @@ var ignoreNonFixedMatches = []match.IgnoreRule{
 	{FixState: string(grypeDb.UnknownFixState)},
 }
 
+var ignoreFixedMatches = []match.IgnoreRule{
+	{FixState: string(grypeDb.FixedState)},
+}
+
 var (
 	rootCmd = &cobra.Command{
 		Use:   fmt.Sprintf("%s [IMAGE]", internal.ApplicationName),
@@ -147,6 +151,11 @@ func setRootFlags(flags *pflag.FlagSet) {
 		"ignore matches for vulnerabilities that are not fixed",
 	)
 
+	flags.BoolP(
+		"only-notfixed", "", false,
+		"ignore matches for vulnerabilities that are fixed",
+	)
+
 	flags.StringArrayP(
 		"exclude", "", nil,
 		"exclude paths from being scanned using a glob expression",
@@ -200,6 +209,10 @@ func bindRootConfigOptions(flags *pflag.FlagSet) error {
 		return err
 	}
 
+	if err := viper.BindPFlag("only-notfixed", flags.Lookup("only-notfixed")); err != nil {
+		return err
+	}
+
 	if err := viper.BindPFlag("exclude", flags.Lookup("exclude")); err != nil {
 		return err
 	}
@@ -284,6 +297,7 @@ func startWorker(userInput string, failOnSeverity *vulnerability.Severity) <-cha
 
 		var store *store.Store
 		var status *db.Status
+		var dbCloser *db.Closer
 		var packages []pkg.Package
 		var context pkg.Context
 		var wg = &sync.WaitGroup{}
@@ -294,7 +308,7 @@ func startWorker(userInput string, failOnSeverity *vulnerability.Severity) <-cha
 		go func() {
 			defer wg.Done()
 			log.Debug("loading DB")
-			store, status, err = grype.LoadVulnerabilityDB(appConfig.DB.ToCuratorConfig(), appConfig.DB.AutoUpdate)
+			store, status, dbCloser, err = grype.LoadVulnerabilityDB(appConfig.DB.ToCuratorConfig(), appConfig.DB.AutoUpdate)
 			if err = validateDBLoad(err, status); err != nil {
 				errs <- err
 				return
@@ -318,10 +332,18 @@ func startWorker(userInput string, failOnSeverity *vulnerability.Severity) <-cha
 			return
 		}
 
+		if dbCloser != nil {
+			defer dbCloser.Close()
+		}
+
 		if appConfig.OnlyFixed {
 			appConfig.Ignore = append(appConfig.Ignore, ignoreNonFixedMatches...)
 		}
 
+		if appConfig.OnlyNotFixed {
+			appConfig.Ignore = append(appConfig.Ignore, ignoreFixedMatches...)
+		}
+
 		applyDistroHint(&context, appConfig)
 
 		matchers := matcher.NewDefaultMatchers(matcher.Config{
