@@ -5,9 +5,10 @@ import (
 
 	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/grype/grype/db"
-	grypeDB "github.com/anchore/grype/grype/db/v3"
+	grypeDB "github.com/anchore/grype/grype/db/v4"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/version"
@@ -37,7 +38,7 @@ func newMockStore() *mockVulnStore {
 }
 
 func (pr *mockVulnStore) stub() {
-	pr.data["nvd"] = map[string][]grypeDB.Vulnerability{
+	pr.data["nvd:cpe"] = map[string][]grypeDB.Vulnerability{
 		"activerecord": {
 			{
 				PackageName:       "activerecord",
@@ -47,7 +48,7 @@ func (pr *mockVulnStore) stub() {
 				CPEs: []string{
 					"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
 				},
-				Namespace: "nvd",
+				Namespace: "nvd:cpe",
 			},
 			{
 				PackageName:       "activerecord",
@@ -57,7 +58,7 @@ func (pr *mockVulnStore) stub() {
 				CPEs: []string{
 					"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:ruby:*:*",
 				},
-				Namespace: "nvd",
+				Namespace: "nvd:cpe",
 			},
 			{
 				PackageName:       "activerecord",
@@ -67,7 +68,7 @@ func (pr *mockVulnStore) stub() {
 				CPEs: []string{
 					"cpe:2.3:*:activerecord:activerecord:4.0.1:*:*:*:*:*:*:*",
 				},
-				Namespace: "nvd",
+				Namespace: "nvd:cpe",
 			},
 		},
 		"awesome": {
@@ -79,7 +80,7 @@ func (pr *mockVulnStore) stub() {
 				CPEs: []string{
 					"cpe:2.3:*:awesome:awesome:*:*:*:*:*:*:*:*",
 				},
-				Namespace: "nvd",
+				Namespace: "nvd:cpe",
 			},
 		},
 		"multiple": {
@@ -94,7 +95,7 @@ func (pr *mockVulnStore) stub() {
 					"cpe:2.3:*:multiple:multiple:2.0:*:*:*:*:*:*:*",
 					"cpe:2.3:*:multiple:multiple:3.0:*:*:*:*:*:*:*",
 				},
-				Namespace: "nvd",
+				Namespace: "nvd:cpe",
 			},
 		},
 	}
@@ -104,6 +105,19 @@ func (pr *mockVulnStore) GetVulnerability(namespace, pkg string) ([]grypeDB.Vuln
 	return pr.data[namespace][pkg], nil
 }
 
+func (pr *mockVulnStore) GetAllVulnerabilities() (*[]grypeDB.Vulnerability, error) {
+	return nil, nil
+}
+
+func (pr *mockVulnStore) GetVulnerabilityNamespaces() ([]string, error) {
+	keys := make([]string, 0, len(pr.data))
+	for k := range pr.data {
+		keys = append(keys, k)
+	}
+
+	return keys, nil
+}
+
 func TestFindMatchesByPackageCPE(t *testing.T) {
 	matcher := match.RubyGemMatcher
 	tests := []struct {
@@ -144,7 +158,7 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							Type:       match.CPEMatch,
 							Confidence: 0.9,
 							SearchedBy: CPEParameters{
-								Namespace: "nvd",
+								Namespace: "nvd:cpe",
 								CPEs:      []string{"cpe:2.3:*:activerecord:activerecord:3.7.5:rando4:*:re:*:rails:*:*"},
 							},
 							Found: CPEResult{
@@ -194,7 +208,7 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 								CPEs: []string{
 									"cpe:2.3:*:activerecord:activerecord:3.7.3:rando4:*:re:*:rails:*:*",
 								},
-								Namespace: "nvd",
+								Namespace: "nvd:cpe",
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"},
@@ -226,7 +240,7 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							Confidence: 0.9,
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:activerecord:activerecord:3.7.3:rando1:*:ra:*:ruby:*:*"},
-								Namespace: "nvd",
+								Namespace: "nvd:cpe",
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:ruby:*:*"},
@@ -270,7 +284,7 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							Confidence: 0.9,
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:*:activerecord:4.0.1:*:*:*:*:*:*:*"},
-								Namespace: "nvd",
+								Namespace: "nvd:cpe",
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:activerecord:activerecord:4.0.1:*:*:*:*:*:*:*"},
@@ -322,7 +336,7 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							Confidence: 0.9,
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:awesome:awesome:98SE1:rando1:*:ra:*:dunno:*:*"},
-								Namespace: "nvd",
+								Namespace: "nvd:cpe",
 							},
 							Found: CPEResult{
 								CPEs:              []string{"cpe:2.3:*:awesome:awesome:*:*:*:*:*:*:*:*"},
@@ -367,7 +381,7 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 							Confidence: 0.9,
 							SearchedBy: CPEParameters{
 								CPEs:      []string{"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*"},
-								Namespace: "nvd",
+								Namespace: "nvd:cpe",
 							},
 							Found: CPEResult{
 								CPEs: []string{
@@ -386,7 +400,9 @@ func TestFindMatchesByPackageCPE(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			actual, err := ByPackageCPE(db.NewVulnerabilityProvider(newMockStore()), test.p, matcher)
+			p, err := db.NewVulnerabilityProvider(newMockStore())
+			require.NoError(t, err)
+			actual, err := ByPackageCPE(p, test.p, matcher)
 			assert.NoError(t, err)
 			assertMatchesUsingIDsForVulnerabilities(t, test.expected, actual)
 			for idx, e := range test.expected {
@@ -457,7 +473,7 @@ func TestAddMatchDetails(t *testing.T) {
 			existing: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -472,7 +488,7 @@ func TestAddMatchDetails(t *testing.T) {
 			},
 			new: match.Detail{
 				SearchedBy: CPEParameters{
-					Namespace: "nvd",
+					Namespace: "nvd:cpe",
 					CPEs: []string{
 						"totally-different-search",
 					},
@@ -487,7 +503,7 @@ func TestAddMatchDetails(t *testing.T) {
 			expected: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -501,7 +517,7 @@ func TestAddMatchDetails(t *testing.T) {
 				},
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"totally-different-search",
 						},
@@ -520,7 +536,7 @@ func TestAddMatchDetails(t *testing.T) {
 			existing: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -550,7 +566,7 @@ func TestAddMatchDetails(t *testing.T) {
 			expected: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -583,7 +599,7 @@ func TestAddMatchDetails(t *testing.T) {
 			existing: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -598,7 +614,7 @@ func TestAddMatchDetails(t *testing.T) {
 			},
 			new: match.Detail{
 				SearchedBy: CPEParameters{
-					Namespace: "nvd",
+					Namespace: "nvd:cpe",
 					CPEs: []string{
 						"totally-different-search",
 					},
@@ -613,7 +629,7 @@ func TestAddMatchDetails(t *testing.T) {
 			expected: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 							"totally-different-search",
@@ -633,7 +649,7 @@ func TestAddMatchDetails(t *testing.T) {
 			existing: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -658,7 +674,7 @@ func TestAddMatchDetails(t *testing.T) {
 			expected: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -677,7 +693,7 @@ func TestAddMatchDetails(t *testing.T) {
 			existing: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
@@ -692,7 +708,7 @@ func TestAddMatchDetails(t *testing.T) {
 			},
 			new: match.Detail{
 				SearchedBy: CPEParameters{
-					Namespace: "nvd",
+					Namespace: "nvd:cpe",
 					CPEs: []string{
 						"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 					},
@@ -702,7 +718,7 @@ func TestAddMatchDetails(t *testing.T) {
 			expected: []match.Detail{
 				{
 					SearchedBy: CPEParameters{
-						Namespace: "nvd",
+						Namespace: "nvd:cpe",
 						CPEs: []string{
 							"cpe:2.3:*:multiple:multiple:1.0:*:*:*:*:*:*:*",
 						},
